@@ -1,8 +1,11 @@
-from indicoio.utils import api_handler
+from indicoio.utils.api import api_handler
+from indicoio.utils.decorators import detect_batch_decorator
 
-def language(api_root, text, batch=False, auth=None, **kwargs):
+
+@detect_batch_decorator
+def language(text, cloud=None, batch=False, api_key=None, version=None, **kwargs):
     """
-    Given input text, returns a probability distribution over 33 possible 
+    Given input text, returns a probability distribution over 33 possible
     languages of what language the text was written in.
 
     Example usage:
@@ -22,5 +25,5 @@ def language(api_root, text, batch=False, auth=None, **kwargs):
     :type text: str or unicode
     :rtype: Dictionary of language probability pairs
     """
-    
-    return api_handler(text, api_root + "language", batch=batch, auth=auth, **kwargs)
+    url_params = {"batch": batch, "api_key": api_key, "version": version}
+    return api_handler(text, cloud=cloud, api="language", url_params=url_params, **kwargs)
