@@ -1,6 +1,9 @@
-from indicoio.utils import api_handler
+from indicoio.utils.api import api_handler
+from indicoio.utils.decorators import detect_batch_decorator
 
-def text_tags(api_root, text, batch=False, auth=None, **kwargs):
+
+@detect_batch_decorator
+def text_tags(text, cloud=None, batch=False, api_key=None, version=None, **kwargs):
     """
     Given input text, returns a probability distribution over 100 document categories
 
@@ -21,5 +24,5 @@ def text_tags(api_root, text, batch=False, auth=None, **kwargs):
     :type text: str or unicode
     :rtype: Dictionary of class probability pairs
     """
-    
-    return api_handler(text, api_root + "texttags", batch=batch, auth=auth, **kwargs)
+    url_params = {"batch": batch, "api_key": api_key, "version": version}
+    return api_handler(text, cloud=cloud, api="texttags", url_params=url_params, **kwargs)
